@@ -20,7 +20,7 @@ REPO_MAINTAINERS = [
 ]
 
 # Package version in the format (major, minor, release)
-PACKAGE_VERSION_TUPLE = (0, 11, 0)
+PACKAGE_VERSION_TUPLE = (0, 11, 2)
 
 # Short description of the package
 PACKAGE_SHORT_DESCRIPTION = "A composable, maintainable system for managing templates"
@@ -66,6 +66,9 @@ PACKAGE_INSTALL_REQUIRES = [
     "cookiecutter",
     "copier",
     "gitpython",
+    # Should be able to remove click version fix after typer puts patch for
+    # ImportError: cannot import name 'get_terminal_size' from 'click.termui'
+    "click<8.1",
     "typer",
     "rich",
     "markupsafe<2.1",
